psychopy_ext.models.HMAX.get_gaussians — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.models.HMAX.get_gaussians

`HMAX.` `get_gaussians`(filter_sizes_all, n_ori=4, sigDivisor=4.0)

  Generates 2D difference of Gaussians (DoG) filters. This function is a faster, more accurate and more elegant version of the original gaussian_filters_matlab but will not produce identical filters as the original (but very close). For practical purposes, this one is prefered. In case you want to mimic the identical behavior of the original HMAX, use gaussian_filters_matlab.

  Parameters
    filter_sizes_all: list (depth 2))
      A nested list (grouped by filter bands) of integer filter sizes
    n_ori: int
      A number of filter orientations (default: 4) Orientations are spaced by np.pi/n_ori
    sigDivisor: float
      A parameter to adjust DoG filter frequency (default: 4.)
  Returns
    gaussians: list (depth 2)
      A nested list of filters of all orientations